from setuptools import setup

setup(name='distributions_nik',
      version='1.2',
      description='Gaussian and Binomial distributions',
      packages=['distributions_nik'],
      author = 'niks_2708',
      zip_safe = False)
